BrokerHandle

Struct BrokerHandle 

pub struct BrokerHandle {
    pub state: Arc<BrokerState>,
    pub url: String,
    /* private fields */
}
Handle to a running broker, including the optional flush thread.

When dropped, signals the flush thread to stop and joins it, then shuts down the tokio runtime. If the handle is in “reattached” mode (connected to an existing broker), dropping it is a no-op.

Fields

state: Arc<BrokerState>

Shared broker state.

url: String

The URL the broker is listening on.