Module config

Module config 

Configuration file support.

Parses TOML configuration from global (~/.config/git-paw/config.toml) and per-repo (.git-paw/config.toml) files. Supports custom CLI definitions, presets, and programmatic add/remove of custom CLIs.

Structs

CustomCli
A custom CLI definition from config.
PawConfig
Top-level git-paw configuration.
Preset
A named preset defining branches and a CLI to use.

Functions

add_custom_cli
Adds a custom CLI to the global config.
add_custom_cli_to
Adds a custom CLI to the config at the given path.
global_config_path
Returns the path to the global config file (~/.config/git-paw/config.toml).
load_config
Loads the merged configuration for a repository.
load_config_from
Loads merged config from an explicit global path and repo root.
remove_custom_cli
Removes a custom CLI from the global config.
remove_custom_cli_from
Removes a custom CLI from the config at the given path.
repo_config_path
Returns the path to a repo-level config file (.git-paw/config.toml).