prune_worktrees

Function prune_worktrees 

pub fn prune_worktrees(repo_root: &Path) -> Result<(), PawError>
Prunes stale worktree registrations from the git worktree list.

This should be called before creating new worktrees to avoid conflicts.