pub struct WorktreeCreation {
pub path: PathBuf,
pub branch_created: bool,
}Expand description
Creates a git worktree for the given branch.
The worktree is placed in the parent directory of repo_root, named using
worktree_dir_name. Returns the path to the created worktree.
Result of creating a worktree, including whether the branch was newly created.
Fields
path: PathBufPath to the created worktree directory.
branch_created: boolWhether git-paw created the branch (true) or it already existed (false).