SpecBackend

Trait SpecBackend 

pub trait SpecBackend: Debug {
    // Required method
    fn scan(&self, dir: &Path) -> Result<Vec<SpecEntry>, PawError>;
}
Trait for format-specific spec scanning backends.

Each spec format (OpenSpec, Markdown) implements this trait to provide discovery of pending specs within a directory.

Required Methods

fn scan(&self, dir: &Path) -> Result<Vec<SpecEntry>, PawError>

Scans dir for pending specs and returns them as SpecEntry values.

Implementors