attach

Function attach 

pub fn attach(name: &str) -> Result<(), PawError>
Attach the current terminal to the named tmux session.

This replaces the current process’s stdio. Returns an error if the session does not exist or tmux fails.