Configuration file support.
Parses TOML configuration from global (~/.config/git-paw/config.toml)
and per-repo (.git-paw/config.toml) files. Supports custom CLI definitions,
presets, and programmatic add/remove of custom CLIs.
Structs
- Broker
Config - HTTP broker configuration for agent coordination.
- Custom
Cli - A custom CLI definition from config.
- Logging
Config - Session logging configuration.
- PawConfig
- Top-level git-paw configuration.
- Preset
- A named preset defining branches and a CLI to use.
- Specs
Config - Spec scanning configuration.
Functions
- add_
custom_ cli - Adds a custom CLI to the global config.
- add_
custom_ cli_ to - Adds a custom CLI to the config at the given path.
- generate_
default_ config - Returns a default
config.tomlstring with sensible defaults and commented-out v0.2.0 fields for discoverability. - global_
config_ path - Returns the path to the global config file (
~/.config/git-paw/config.toml). - load_
config - Loads the merged configuration for a repository.
- load_
config_ from - Loads merged config from an explicit global path and repo root.
- load_
repo_ config - Loads only the repo-level configuration (
.git-paw/config.toml). - remove_
custom_ cli - Removes a custom CLI from the global config.
- remove_
custom_ cli_ from - Removes a custom CLI from the config at the given path.
- repo_
config_ path - Returns the path to a repo-level config file (
.git-paw/config.toml). - save_
repo_ config - Saves a
PawConfigto the repo-level config file (.git-paw/config.toml).