pub fn parse_pane_paths(output: &str) -> Vec<(usize, String)>Expand description
Parses tmux list-panes -F '#{pane_index} #{pane_current_path}' output
into (pane_index, current_path) pairs.
Lines that do not start with a numeric pane index are skipped. The path is the remainder of the line (paths never contain the separating space at the front, and may themselves contain spaces).