exclude_from_git

Function exclude_from_git 

pub fn exclude_from_git(
    worktree_root: &Path,
    filename: &str,
) -> Result<(), PawError>
Excludes a file from git tracking by adding it to .git/info/exclude.

This prevents the file from being tracked by git without modifying the repository’s .gitignore file, which is useful for worktree-specific files that should not be committed.